/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.ranger.authorization.hbase;

import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
import org.apache.hadoop.hbase.security.access.Permission.Action;

public interface HbaseAuthUtils {
	String ACCESS_TYPE_READ   = "read";
	String ACCESS_TYPE_WRITE  = "write";
	String ACCESS_TYPE_CREATE = "create";
	String ACCESS_TYPE_ADMIN  = "admin";
	String ACCESS_TYPE_EXECUTE  = "execute";

	String getAccess(Action action);

	String getActionName(String access);

	boolean isReadAccess(String access);
	
	boolean isWriteAccess(String access);

	boolean isExecuteAccess(String access);

	String getTable(RegionCoprocessorEnvironment regionServerEnv);
}
